==> opentsdb_python_metrics-0.1.8.tar.gz: opentsdb_python_metrics-0.1.8/setup.py <==
#!/usr/bin/python
# Copyright (c) 2009 Las Cumbres Observatory.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, find_packages


DESCRIPTION = """Library for collecting and storing metrics from python methods"""


setup(
    name='opentsdb_python_metrics',
    version='0.1.8',
    description=DESCRIPTION,
    long_description=DESCRIPTION,
    author='Jon Nation',
    author_email='jnation@lco.global',
    packages=['opentsdb_python_metrics'],
    install_requires=['opentsdb_http_client'],
    license="GNU GPL",
    tests_require=['nose', 'requests'],
    test_suite="nose.collector",
)

==> opentsdb_python_metrics-0.2.0.tar.gz: opentsdb_python_metrics-0.2.0/setup.py <==
#!/usr/bin/python
# Copyright (c) 2009 Las Cumbres Observatory.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, find_packages


DESCRIPTION = """Library for collecting and storing metrics from python methods"""


setup(
    name='opentsdb_python_metrics',
    version='0.2.0',
    description=DESCRIPTION,
    long_description=DESCRIPTION,
    author='Jon Nation',
    author_email='jnation@lco.global',
    packages=['opentsdb_python_metrics'],
    install_requires=['opentsdb_http_client>=0.2.0'],
    license="GNU GPL",
    tests_require=['nose', 'requests'],
    test_suite="nose.collector",
)
